@@ -40,6 +40,7 @@ my %OK_PROPS = @OK_PROPS;
 sub ACTION_demo {
     my $self = shift;
     $self->depends_on('config_data');
+    $self->depends_on('build');
 
     my $dir  = tempdir(
 	'GBrowse_demo_XXXX',
@@ -808,8 +809,9 @@ HostnameLookups Off
    LoadModule log_config_module $modules/mod_log_config.so
  </IfModule>
 
- <IfModule !cgi_module>
-  LoadModule cgi_module         $modules/mod_cgi.so
+ <IfModule !cgid_module>
+  LoadModule cgid_module         $modules/mod_cgid.so
+  ScriptSock "$dir/logs/cgisock"
  </IfModule>
 
  <IfModule !authz_host_module>
